"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ingestJobOffers = void 0;
const client_1 = require("@prisma/client");
const FranceTravailService_1 = __importDefault(require("../services/FranceTravailService"));
const prisma = new client_1.PrismaClient();
const ingestJobOffers = (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b, _c, _d, _e;
    try {
        const jobOffers = yield FranceTravailService_1.default.getJobOffers({ range: '0-149' });
        for (const offre of jobOffers.resultats) {
            const mappedOffer = {
                id: offre.id,
                title: offre.intitule,
                description: offre.description,
                publicationDate: new Date(offre.dateCreation),
                romeCode: offre.romeCode,
                romeLabel: offre.romeLibelle,
                locationLabel: ((_a = offre.lieuTravail) === null || _a === void 0 ? void 0 : _a.libelle) || null,
                postalCode: ((_b = offre.lieuTravail) === null || _b === void 0 ? void 0 : _b.codePostal) || null,
                departmentCode: ((_c = offre.lieuTravail) === null || _c === void 0 ? void 0 : _c.codeDepartement) || null,
                cityName: ((_d = offre.lieuTravail) === null || _d === void 0 ? void 0 : _d.ville) || null,
                companyName: ((_e = offre.entreprise) === null || _e === void 0 ? void 0 : _e.nom) || null,
                contractType: offre.typeContrat,
                contractLabel: offre.libelleTypeContrat,
            };
            yield prisma.jobOffer.upsert({
                where: { id: mappedOffer.id },
                update: mappedOffer,
                create: mappedOffer,
            });
        }
        res.status(200).json({
            message: 'Job offers ingested successfully',
            count: jobOffers.resultats.length,
        });
    }
    catch (error) {
        console.error('Error ingesting job offers:', error);
        res.status(500).json({ error: 'Failed to ingest job offers' });
    }
});
exports.ingestJobOffers = ingestJobOffers;
