import { Request, Response } from 'express';
import { PrismaClient } from '@prisma/client';
import FranceTravailService from '../services/FranceTravailService';

const prisma = new PrismaClient();

export const ingestJobOffers = async (req: Request, res: Response) => {
  try {
    const jobOffers = await FranceTravailService.getJobOffers({ range: '0-149' });

    for (const offre of jobOffers.resultats) {
      const mappedOffer = {
        id: offre.id,
        title: offre.intitule,
        description: offre.description,
        publicationDate: new Date(offre.dateCreation),
        romeCode: offre.romeCode,
        romeLabel: offre.romeLibelle,
        locationLabel: offre.lieuTravail?.libelle || null,
        postalCode: offre.lieuTravail?.codePostal || null,
        departmentCode: offre.lieuTravail?.codeDepartement || null,
        cityName: offre.lieuTravail?.ville || null,
        companyName: offre.entreprise?.nom || null,
        contractType: offre.typeContrat,
        contractLabel: offre.libelleTypeContrat,
      };

      await prisma.jobOffer.upsert({
        where: { id: mappedOffer.id },
        update: mappedOffer,
        create: mappedOffer,
      });
    }

    res.status(200).json({
      message: 'Job offers ingested successfully',
      count: jobOffers.resultats.length,
    });
  } catch (error) {
    console.error('Error ingesting job offers:', error);
    res.status(500).json({ error: 'Failed to ingest job offers' });
  }
};
